<img style="float: right;" src="https://imaging.epfl.ch/resources/logo-for-gitlab.svg">

# ome2glancer
This package creates neuroglancer links to open ome-zarr files.

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14762266.svg)](https://doi.org/10.5281/zenodo.14762266)
